@@ -1,11 +1,11 @@
-context("gisd functions")
-
-test_that("gisd works", {
+test_that("flora_europaea", {
   skip_on_cran()
 
   sp <- c("Carpobrotus edulis", "Rosmarinus officinalis")
-  aa <- flora_europaea(sp[1], messages = FALSE)
-  bb <- flora_europaea(sp[2], messages = FALSE)
+  vcr::use_cassette("flora_europaea", {
+    aa <- flora_europaea(sp[1], messages = FALSE)
+    bb <- flora_europaea(sp[2], messages = FALSE)
+  })
 
   expect_is(aa, "list")
   expect_named(aa, c('native', 'exotic', 'status_doubtful', 'occurrence_doubtful', 'extinct'))
@@ -18,10 +18,12 @@ test_that("gisd works", {
   expect_is(bb$exotic, "character")
 })
 
-test_that("fails well - species not found when searching GBIF", {
+test_that("flora_europaea fails well - species not found when searching GBIF", {
   skip_on_cran()
 
   sp <- "asdfadsf"
-  aa <- flora_europaea(sp, messages = FALSE)
-  expect_null(aa)
+  vcr::use_cassette("flora_europaea_fail", {
+    cc <- flora_europaea(sp, messages = FALSE)
+  })
+  expect_null(cc)
 })
